Plots for Glycoverse Data Containers
autoplot.glyexp_experiment.RdVisualization for glyexp::GlycomicSE(), glyexp::GlycoproteomicSE(),
and other compatible SummarizedExperiment objects.
Possible types of plots:
"heatmap": (Default) Expression heatmap with columns as samples and rows as variables.
"boxplot": Boxplot of expression values for each sample.
Arguments
- object
A supported Glycoverse data container.
- type
The type of plot, one of "heatmap" (default) or "boxplot".
- group_col
A character string specifying where to find the group information. It should be a column in the sample information tibble. Defaults to "group". Only applicable to "boxplot".
- ...
Ignored.