Plots for t-SNE
autoplot.glystats_tsne_res.RdVisualization for results from glystats::gly_tsne() (glystats_tsne_res objects).
Draw a scatter plot of t-SNE coordinates.
Usage
# S3 method for class 'glystats_tsne_res'
autoplot(object, groups = NULL, group_col = NULL, ...)Arguments
- object
A
glystats_tsne_resobject.- groups
A factor or character vector specifying group membership for each sample. If provided, the plot will be colored by group.
- group_col
A character string specifying where to find the group information. If the result was produced from a supported Glycoverse data container, sample information has already been added to the result. In this case, you can specify the column name in the sample information tibble to be used for coloring. If not provided, this function will try "group".
- ...
Ignored.